@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/07/10 11:05:07 $
-# $Revision: 1.18.1.167 $
+# $Date: 1998/07/14 09:32:13 $
+# $Revision: 1.18.1.170 $
 #
 #
 package provide zircon 1.18
@@ -271,12 +271,10 @@ proc channel_kickUser {this usr prefix kill} {
 #
 proc channel_killUser {this usr} {
     upvar #0 $this cdata
-    set w $cdata(window)
     catch {destroy $cdata(ufrm).userBtn.$usr}
-    catch {
-	if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
-	    $w.users.menu delete $x
-	}
+    set w $cdata(window)
+    if {[set x [indexHack $w.users.menu [$usr name] 3]] >=0} {
+	$w.users.menu delete $x
     }
     catch {$this delTag $usr}
     catch {$usr leave $this}
@@ -770,13 +768,10 @@ proc channel_toggle {this val win} {
 }
 #
 proc channel_remove {this usr} {
-    if {[$this isJoined $usr] &&
-      ![normal [$this ufrm].userBtn.$usr]} {
+    if {[$this isJoined $usr]} {
 	$this killUser $usr
     } elseif {[$this monitor]} {
-	switch {} [$this mwin] {} default {
-	    [$this mwin] remove $usr
-	}
+	switch {} [$this mwin] {} default { [$this mwin] remove $usr }
     }
 }
 #
@@ -849,12 +844,12 @@ proc makeCtlInfo {this net w chan rchan idx look} {
     if {[$this isa Channel]} {
 	set om [makeMB $w.channel Channel]
 	addImage $w.channel channel $w.cmds $idx $net
-	$om add command -command "$net q1Send {WHO :$rchan}" -label [trans who]
-	$om add command -command "userInvite $net {$chan}" -label [trans invite]
-	$om add command -command "channelNotice $net {$chan}" -label [trans notice]
+	$om add command -command "$net WHO [list $rchan]" -label [trans who]
+	$om add command -command "userInvite $net [list $chan]" -label [trans invite]
+	$om add command -command "channelNotice $net [list $chan]" -label [trans notice]
 	$om add cascade -label [trans messages] -menu $om.msgs
 	set omm [menu $om.msgs]
-	catch {$omm configure  -tearoffcommand "retitle {Messages for $chan}"}
+	catch {$omm configure  -tearoffcommand "retitle [list Messages for $chan]"}
 	$omm add command -label [trans new] -command "$this newMsg"
 	$omm add separator
 	foreach x [$this messages] {
@@ -1094,7 +1089,7 @@ proc channel_cmdState {this} {
     catch {$w.action configure -state $st}
     if {[winfo exists [set mn $w.channel.menu]]} {
 	foreach x {notice messages draw ctcp sound} {
-	    $mn entryconfigure [$mn index [trans $x]] -state $st
+	    catch {$mn entryconfigure [$mn index [trans $x]] -state $st}
 	}
     }
 }
@@ -1884,7 +1879,7 @@ proc channel_showFlags {this lb txt} {
     upvar #0 $this cdata
     if {[winfo exists [set w $cdata(window).cflags]]} {
 	switch {} $txt {
-	    grid forget $w.$lb
+	    catch {grid forget $w.$lb}
 	} default {
 	    if {![winfo ismapped $w.$lb]} {
 		grid $w.$lb -row 0 -column [lindex [grid size $w] 0]
@@ -1907,8 +1902,7 @@ proc channel_showFlags {this lb txt} {
 proc channel_search {this} {
     global Search zircon
     if {[winfo exists [set w .@srch$this]]} { popup $w ; return }
-    toplevel $w -class Zircon
-    wm title $w "Search [$this name]"
+    makeToplevel $w "Search [$this name]" {} {}
     labelEntry 0 $w.search {-text [list [trans {search string}]]} {} "$this doSearch $w"
     $w.search.entry configure -textvariable Search($this,term)
     grid $w.search - -row 0 -sticky ew
