@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Classes.tcl,v $
-# $Date: 1998/06/25 10:55:49 $
-# $Revision: 1.18.1.83 $
+# $Date: 1998/07/14 09:32:15 $
+# $Revision: 1.18.1.86 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -15,49 +15,49 @@ proc InitClasses {} {
     dispAd {Initialising classes...}
 #
 class Channel {
-    timestamp	0	{bool}
-    noshare	0	{bool}
+    timestamp	0	{bool {Display Timestamps}}
+    noshare	0	{bool {Do Not Share}}
     monitor	0	{bool}
-    menu	0	{bool {On Menu}}
-    join	0	{bool}
-    nocase	0	{bool {Ignore Case}}
-    nosort	0	{bool {Do not sort}}
+    menu	0	{bool {Add to Channel Menu}}
+    join	0	{bool {Join at Startup}}
+    nocase	0	{bool {Ignore nick case}}
+    nosort	0	{bool {Do not sort nicks}}
     noshow	0	{bool}
-    open	0	{bool}
-    close	0	{bool}
-    draw	1	{bool}
-    jump	1	{bool}
-    quiet	0	{bool}
-    actions	0	{bool}
-    buttons	1	{bool}
-    closeleave	0	{bool}
-    colour	{}	{list {mirc ansi ctcp2}}
-    crypt	{}	{sedkey}
-    key		{}	{key}
-    logfile	{}	{file}
-    history	10	{int}
-    scrollback	50	{int}
-    closetime	0	{mseconds}
-    patterns	{}	{patterns}
-    messages	{}	{texts}
-    topics	{}	{texts}
-    ops		{}	{users}
-    ban		{}	{users}
-    msg		{}	{list {Join Kick Kill Leave Lost Back Mode Quit Topic}}
-    bindings	{}	{special}
-    icon	{}	{icon}
-    foreground	{}	{colour}
-    background	{}	{colour}
-    font	{}	{font}
-    boldfont	{}	{font}
-    geometry	{}	{geometry}
-    height	24	{int}
-    width	80	{int}
-    timeformat  {%m/%d/%Y %H:%M:%S}	{format}
-    joinat	{}	{time}
-    mytag	{>}	{prompt}
-    logtag	{>}	{prompt}
-    iconify	{iconify} {operator}
+    open	0	{bool {Pop up when active}}
+    close	0	{bool {Close if inactive}}
+    draw	1	{bool {Enable whiteboard}}
+    jump	1	{bool {Scroll}}
+    quiet	0	{bool {No Bell}}
+    actions	0	{bool {Action mode}}
+    buttons	1	{bool {Show Name Buttons}}
+    closeleave	0	{bool {Leave if inactive}}
+    colour	{}	{checks {mirc ansi ctcp2} {Colour Support}}
+    crypt	{}	{sedkey {}}
+    key		{}	{key {}}
+    logfile	{}	{file {}}
+    history	10	{int {}}
+    scrollback	50	{int {}}
+    closetime	0	{mseconds {}}
+    patterns	{}	{patterns {}}
+    messages	{}	{texts {}}
+    topics	{}	{texts {}}
+    ops		{}	{users {}}
+    ban		{}	{users {}}
+    msg		{}	{list {Join Kick Kill Leave Lost Back Mode Quit Topic} {}}
+    bindings	{}	{special {}}
+    icon	{}	{icon {}}
+    foreground	{}	{colour {}}
+    background	{}	{colour {}}
+    font	{}	{font {}}
+    boldfont	{}	{font {}}
+    geometry	{}	{geometry {}}
+    height	24	{int {}}
+    width	80	{int {}}
+    timeformat  {%m/%d/%Y %H:%M:%S}	{format {}}
+    joinat	{}	{time {}}
+    mytag	{>}	{prompt {}}
+    logtag	{>}	{prompt {}}
+    iconify	{iconify} {operator {}}
 } {
     name	{}
     lname	{}
@@ -203,6 +203,7 @@ class Friend {
     lnick	{}
     net		{}
     usr		nil
+    keep	1
     ison	0
     limbo	0
     images	{}
@@ -282,6 +283,8 @@ class Net "
     nicksize	9	{int {Max. Nickname Size}}
     dccblock	2048	{int {DCC Blocksize}}
 " {
+    globfriend	{}
+    whohandler	{}
     restricted	0
     name	{}
     sock	{}
@@ -336,6 +339,7 @@ class Net "
     services	{}
     motdSeen	0
     lastuser	{}
+    lastwho	{}
     atchn	0
     atsrv	0
     atcll	0
