@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Control.tcl,v $
-# $Date: 1998/07/10 11:05:10 $
-# $Revision: 1.18.1.98 $
+# $Date: 1998/07/13 09:33:39 $
+# $Revision: 1.18.1.100 $
 #
 #
 package provide zircon 1.18
@@ -133,11 +133,12 @@ proc nickKeys {net win} {
 #
 proc MainControl {} {
     if {![winfo exists .@ctl]} {
-	global zircon zlayout zCtl DEBUG
+	global zircon zlayout zCtl DEBUG argv0 argv
 	set zCtl [Window .@ctl -title {Zircon Control Panel} -resizable {1 1}]
 	set ctl [$zCtl name]
 	catch {wm geometry $ctl $zlayout(default,control)}
 	wm protocol .@ctl WM_DELETE_WINDOW leaveZircon
+	wm protocol .@ctl WM_SAVE_YOURSELF "wm command .@ctl {$argv0 $argv}"
 	grid columnconfigure .@ctl 0 -weight 1
 	grid [set hf [frame $ctl.helpFrm -borderwidth 0]] -sticky ew
 	set om [makeMB $hf.info "Zircon V$zircon(version)"]
@@ -289,10 +290,8 @@ proc reread {} {
 proc faves {net} {
     if {[winfo exists [set w .@faves$net]]} {popup $w ; return}
     global defChan
-    toplevel $w -class Zircon
-    wm title $w Favourites
+    makeToplevel $w Favourites "killWindow $w" {}
     wm resizable $w 0 1
-    wm protocol $w WM_DELETE_WINDOW "killWindow $w"
     scrollbar $w.vscroller -command "$w.chList yview" 
     text $w.chList -yscrollcommand "$w.vscroller set" -width 14 \
       -height 12
@@ -593,7 +592,9 @@ proc netspaceMenu {w} {
     if {![file exists [set ns [file join $zircon(prefdir) netspaces]]]} {
 	$w.spaces configure -state disabled
     } {
-	foreach x [lsort [glob -nocomplain [file join $ns *]]] { addNS $om $x }
+	foreach x [lsort [glob -nocomplain [file join $ns *]]] {
+	    addNS $om $x
+	}
 	$om add separator
     }
 }
@@ -616,15 +617,14 @@ proc setUnload {name state} {
 }
 #
 proc addNS {om x} {
+    global zircon
     set fn [file tail $x]
-    switch -glob -- $fn {
-    *.bak - *.tmp {}
-    default {
-	    set w [newName nsh]
-	    $om add cascade -label $fn -menu $om.$w
-	    nsSubMenu $om $fn $w
-	}
+    foreach x $zircon(nsignore) {
+        if {[string match $x $fn]} return
     }
+    set w [newName nsh]
+    $om add cascade -label $fn -menu $om.$w
+    nsSubMenu $om $fn $w
 }
 #
 proc control_channel {this} { upvar #0 $this cdata ; return $cdata(channel) }
