@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Sound.tcl,v $
-# $Date: 1998/04/23 08:59:13 $
-# $Revision: 1.18.1.12 $
+# $Source: /home/nlfm/Zircon/lib/RCS/Sound.tcl,v $
+# $Date: 1998/06/12 15:04:25 $
+# $Revision: 1.18.1.13 $
 #
 package provide zircon 1.18
 #
@@ -38,7 +38,7 @@ proc handleSound {net usr fl chan prefix} {
 proc doSendSound {net nk fl} {
     switch {} $fl return
     set tfl [file tail [file rootname $fl]]
-    $net CTCP SOUND $nk "$tfl <$tfl>"
+    $net CTCP SOUND $nk "[file tail $fl] <$tfl>"
     handleSound $net [$net nickname] $fl {} {}
 }
 #
