@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Tracing.tcl,v $
-# $Date: 1998/04/29 11:44:30 $
-# $Revision: 1.18.1.30 $
+# $Date: 1998/04/30 13:17:49 $
+# $Revision: 1.18.1.31 $
 #
 #
 package provide Tracing 1.18
@@ -36,7 +36,7 @@ proc ircInput {mode conn} {
 	switch -glob $prefix {
 	:* { }
 	PING {
-		$net qSend PONG :[string range $cmd 1 end]
+		$net q1Send "PONG :[string range $cmd 1 end]"
 		return
 	    }
 	ERROR {
@@ -87,10 +87,11 @@ proc net_qSend {this op args} {
 }
 #
 proc net_sendRaw {this value} {
-    zOut $value $this
     upvar #0 ${this}(sock) sock
-    switch {} $sock return
-    if {[catch {puts $sock $value} msg]} {$this close $msg ; return 1}
+    switch {} $sock {} default {
+	zOut $value $this
+        if {[catch {puts $sock $value} msg]} {$this close $msg ; return 1}
+    }
     return 0
 }
 #
