@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Util.tcl,v $
-# $Date: 1998/07/01 09:34:45 $
-# $Revision: 1.18.1.69 $
+# $Date: 1998/07/14 09:32:22 $
+# $Revision: 1.18.1.71 $
 #
 package provide zircon 1.18
 #
@@ -622,8 +622,7 @@ proc makePalette {w chn prt name ft col} {
     if {[winfo exists $w]} {popup $w ; return} 
     global Ft
     killWindow $w
-    toplevel $w -class Zircon
-    wm title $w "$name Palette"
+    makeToplevel $w "$name Palette" {} {}
     wm resizable $w 0 0
     set row 0
     switch {} $ft {set ft [$prt cget -font]}
@@ -749,4 +748,24 @@ proc fullName {file} {
 proc safeUnset {args} { foreach x $args { catch {uplevel #0 unset $x} msg } }
 #
 proc safeDestroy {args} { foreach x $args { catch {destroy $x} } }
-
+#
+proc makeToplevel {w title del save} {
+    toplevel $w -class Zircon
+    wm title $w $title
+    switch {} $del {} default {
+        wm protocol $w WM_DELETE_WINDOW $del
+    }
+    switch {} $save {set save "wm command $w { }"}
+    wm protocol $w WM_SAVE_YOURSELF $save
+    wm resizable $w 1 1
+    return $w
+}
+#
+proc colonLast {arg} {
+    switch {} [set rest [string trim $arg]] { return {} }
+    if {[set ix [string last { } $rest]] < 0} {
+	return :$rest
+    } {
+	return [string range $rest 0 $ix]:[string range $rest [expr $ix+1] end]
+    }
+}
