@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Window.tcl,v $
-# $Date: 1998/07/09 11:15:00 $
-# $Revision: 1.18.1.35 $
+# $Date: 1998/07/10 13:33:56 $
+# $Revision: 1.18.1.36 $
 #
 package provide zircon 1.18
 #
@@ -17,16 +17,14 @@ proc Window {name args} {
     set wdata(name) $ln
     proc $this {op args} "objCall window $this \$op \$args"
     topAndIcon $ln "$this close"
-    wm resizable $ln 1 1
     eval $this configure $args
     uplevel #0 lappend zWList $this
     return $this
 }
 #
 proc topAndIcon {win del} {
-    global zLogo
-    toplevel $win -class Zircon
-    switch {} $del {} default { wm protocol $win WM_DELETE_WINDOW $del }
+#    global zLogo
+    makeToplevel $win {} $del {}
 #    wm withdraw [toplevel ${win}icon]
 #    pack [label ${win}icon.label -image $zLogo]
 #    wm iconwindow $win ${win}icon
