@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/debug.tcl,v $
-# $Date: 1998/04/23 08:59:21 $
-# $Revision: 1.18.1.34 $
+# $Source: /home/nlfm/Zircon/lib/RCS/debug.tcl,v $
+# $Date: 1998/07/10 13:33:59 $
+# $Revision: 1.18.1.35 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -215,10 +215,8 @@ proc zDBGControl {} {
     global zscr zircon zlayout
     if {[winfo exists .@dbgctl]} { popup .@dbgctl ; return }
     [MainControl].helpFrm.info.menu entryconfigure end -state normal
-    toplevel [set ctl .@dbgctl] -class Zircon
-    wm title $ctl "Zircon Debugger"
-    wm resizable $ctl 1 1
-    wm protocol $ctl WM_DELETE_WINDOW {catch {uplevel #0 unset zscr}}
+    makeToplevel [set ctl .@dbgctl] "Zircon Debugger" \
+      {catch {uplevel #0 unset zscr}} {}
     grid columnconfigure $ctl 0 -weight 1 -minsize 100
     set f [frame $ctl.btn]
     grid columnconfigure $f 0 -weight 1
