@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/dialog.tcl,v $
-# $Date: 1998/06/05 19:34:17 $
-# $Revision: 1.18.1.39 $
+# $Source: /home/nlfm/Zircon/lib/RCS/dialog.tcl,v $
+# $Date: 1998/07/10 13:34:00 $
+# $Revision: 1.18.1.40 $
 #
 package provide zircon 1.18
 #
@@ -81,11 +81,8 @@ proc doEntries {w entries} {
 }
 #
 proc dialogWindow {w title} {
-    toplevel $w -class Zircon
-    wm title $w $title
-    wm protocol $w WM_DELETE_WINDOW {}
+    makeToplevel $w $title {} {}
     wm transient $w [winfo toplevel [winfo parent $w]]
-    wm resizable $w 1 1
     grid columnconfigure $w 0 -weight 1
     grid rowconfigure $w 0 -weight 1
 #
@@ -266,10 +263,7 @@ proc mkFileBox {w dirv filter title msgText init args} {
     switch {} $w {set w .@[newName flb]} default {killFWindow $w}
     global FBFilter
     set FBFilter($w) $filter
-    toplevel $w -class Zircon
-    wm title $w "$title"
-    wm protocol $w WM_DELETE_WINDOW "catch {unset FBFilter($w)}"
-    wm resizable $w 1 1
+    makeToplevel $w $title "catch {unset FBFilter($w)}" {}
     wm transient $w [winfo toplevel [winfo parent $w]]
     frame $w.top -relief raised
     frame $w.mid -borderwidth 0
