@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/misc2.tcl,v $
-# $Date: 1998/06/25 10:55:57 $
-# $Revision: 1.18.1.39 $
+# $Date: 1998/07/14 09:32:29 $
+# $Revision: 1.18.1.40 $
 #
 #
 package provide zircon 1.18
@@ -34,15 +34,6 @@ proc deCap {str} {
     return [list [string range $str 0 [expr {$ix - 1}]] [string range $str [expr {$ix + 1}] end]]
 }
 #
-proc colonLast {arg} {
-    switch {} [set rest [string trim $arg]] { return {} }
-    if {[set ix [string last { } $rest]] < 0} {
-	return :$rest
-    } {
-	return [string range $rest 0 $ix]:[string range $rest [expr $ix+1] end]
-    }
-}
-#
 proc ircII_/ABORT {net chid arg} { exit }
 #
 proc ircII_/ADMIN {net chid arg} { $net nsend ADMIN [lindex $arg 0]}
@@ -519,7 +510,7 @@ proc ircII_/WHICH {net chid arg} { sillyPerson $net }
 #
 proc ircII_/WHILE {net chid arg} { sillyPerson $net }
 #
-proc ircII_/WHO {net chid arg} { $net q1Send "WHO [colonLast $arg]" }
+proc ircII_/WHO {net chid arg} { $net WHO $arg }
 #
 proc ircII_/WHOIS {net chid arg} { $net q1Send "WHOIS [colonLast $arg]" }
 #
