@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/saverc.tcl,v $
-# $Date: 1998/05/07 11:01:35 $
-# $Revision: 1.18.1.26 $
+# $Date: 1998/06/11 08:42:53 $
+# $Revision: 1.18.1.27 $
 #
 package provide zircon 1.18
 #
@@ -186,8 +186,10 @@ proc saveCurrent {net} {
 }
 #
 proc ditchSize {w} {
-    regexp {.*(\+.*\+.*)} [wm geometry $w] m x
-    return $x
+    if {[regexp {.*(\+.*\+.*)} [wm geometry $w] m x]} {
+        return $x
+    }
+    return 200x100
 }
 #
 proc saveLayout {net} {
