@@ -1,7 +1,7 @@
 #
-# $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dcc.tcl,v $
-# $Date: 1998/05/21 13:31:42 $
-# $Revision: 1.18.1.56 $
+# $Source: /home/nlfm/Zircon/plugins/Dcc/RCS/dcc.tcl,v $
+# $Date: 1998/07/13 09:33:53 $
+# $Revision: 1.18.1.58 $
 #
 package provide Dcc 1.18
 #
@@ -125,8 +125,7 @@ proc addDCCRequest {net op usr fln addr port leng} {
     global DCCList
     if {![winfo exists [set w .@drq$net]]} {
 	set DCCList($net) {}
-	toplevel $w -class Zircon
-	wm title $w "[$net name] - Incoming DCC Offers"
+	makeToplevel $w "[$net name] - Incoming DCC Offers" {} {}
 	addSeparator [switchFrame $w sChat {Chat Offers}] \
 	  -columnspan 5
 	addSeparator [switchFrame $w sSend {File Send Offers}] \
@@ -287,8 +286,7 @@ proc buildDCCList {net args} {
 	    }
 	}
     } {
-	toplevel $w -class Zircon -relief raised -borderwidth 2
-	wm title $w "[$net name] - DCC Connections"
+	makeToplevel $w  "[$net name] - DCC Connections" {} {}
 	wm resizable $w 0 0
 	foreach x {coff achat fOffer fSend fGet} {
 	    set w1 [switchFrame $w $x $tls($x)]
@@ -480,13 +478,12 @@ proc dccProgress {conn bytes pcnt min sec} {
 #
 proc dccWindow {conn usr array file} {
     if {[winfo exists [set w .@$conn]]} return
-    toplevel $w -class Zircon
     switch $array Send {
-	wm title $w "DCC send $file to [$usr name]"
+	set tl "DCC send $file to [$usr name]"
     } default {
-	wm title $w "DCC get $file from [$usr name]"
+	set tl "DCC get $file from [$usr name]"
     }
-    wm protocol $w WM_DELETE_WINDOW {}
+    makeToplevel $w $tl {} {}
     scale $w.slide -from 0 -to 100 -tickinterval 20 \
        -state disabled -length 200 -orient horizontal
     grid columnconfigure $w 0 -weight 1
